@@ -154,6 +154,11 @@ def project_build(docker_image_tag: str) -> None:
     ProjectBuilder.build_project(docker_image_tag)
 
 
+@project.command()
+def project_convert() -> None:
+    ProjectBuilder.convert_jupyter_notebook()
+
+
 @project.command()
 @click.option(
     "--registry-url",
@@ -390,6 +395,7 @@ def docker_login(username: str, password: str, docker_registry_url: str) -> None
 
 project.add_command(project_init, "init")
 project.add_command(project_deploy, "deploy")
+project.add_command(project_convert, "convert")
 project.add_command(project_build, "build")
 project.add_command(project_publish, "publish")
 api_token.add_command(platform_apitoken_create, "create")
